@@ -99,18 +99,18 @@ show_error_dialog()
 	gchar *err_string;
 
 	err_string = g_strdup_printf ( _("Warning: Evolution could not migrate "
-		  			"all the Exchange account data from "
-		  			"the version %d.%d.%d. \nThe data "
-		  			"hasn't been deleted, but will not be "
-		  			"seen by this version of Evolution"),
-		  			maj, min, rev);
+					"all the Exchange account data from "
+					"the version %d.%d.%d. \nThe data "
+					"hasn't been deleted, but will not be "
+					"seen by this version of Evolution"),
+					maj, min, rev);
 
 	window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	error_dialog = gtk_message_dialog_new (GTK_WINDOW (window),
 					       GTK_DIALOG_DESTROY_WITH_PARENT,
 					       GTK_MESSAGE_ERROR,
 					       GTK_BUTTONS_OK,
-					       err_string);
+					       "%s", err_string);
 	gtk_dialog_run (GTK_DIALOG (error_dialog));
 	gtk_widget_destroy (error_dialog);
 
@@ -125,9 +125,9 @@ dialog_close ()
 }
 
 static void
-dialog_set_folder_name (const char *folder_name)
+dialog_set_folder_name (const gchar *folder_name)
 {
-	char *text;
+	gchar *text;
 
 	text = g_strdup_printf (_("Migrating `%s':"), folder_name);
 	gtk_label_set_text (label, text);
@@ -142,9 +142,9 @@ dialog_set_folder_name (const char *folder_name)
 static void
 dialog_set_progress (double percent)
 {
-	char text[5];
+	gchar text[5];
 
-	snprintf (text, sizeof (text), "%d%%", (int) (percent * 100.0f));
+	snprintf (text, sizeof (text), "%d%%", (gint) (percent * 100.0f));
 
 	gtk_progress_bar_set_fraction (progress, percent);
 	gtk_progress_bar_set_text (progress, text);
@@ -154,17 +154,17 @@ dialog_set_progress (double percent)
 }
 
 static gboolean
-cp (const char *src, const char *dest, gboolean show_progress)
+cp (const gchar *src, const gchar *dest, gboolean show_progress)
 {
-	unsigned char readbuf[65536];
-	ssize_t nread, nwritten;
-	int errnosav, readfd, writefd;
-	size_t total = 0;
+	guchar readbuf[65536];
+	gssize nread, nwritten;
+	gint errnosav, readfd, writefd;
+	gsize total = 0;
 	struct stat st;
 	struct utimbuf ut;
 
 	/* if the dest file exists and has content, abort - we don't
- 	 * want to corrupt their existing data */
+	 * want to corrupt their existing data */
 
         if (stat (dest, &st) == 0 && st.st_size > 0)
 		goto ret;
@@ -201,7 +201,7 @@ cp (const char *src, const char *dest, gboolean show_progress)
                 total += nwritten;
 
                 if (show_progress)
-                	dialog_set_progress ((((double) total) /
+			dialog_set_progress ((((double) total) /
 					      ((double) st.st_size)));
         } while (total < st.st_size);
 
@@ -236,11 +236,11 @@ cp (const char *src, const char *dest, gboolean show_progress)
 }
 
 static gboolean
-cp_r (char *src, const char *dest)
+cp_r (gchar *src, const gchar *dest)
 {
 	GString *srcpath, *destpath;
 	struct dirent *dent;
-	size_t slen, dlen;
+	gsize slen, dlen;
 	struct stat st;
 	DIR *dir;
 
@@ -262,7 +262,7 @@ cp_r (char *src, const char *dest)
 
 	while ((dent = readdir (dir))) {
 		if (!strcmp (dent->d_name, ".") || !strcmp (dent->d_name, ".."))
-                	continue;
+			continue;
 
 		g_string_truncate (srcpath, slen);
 		g_string_truncate (destpath, dlen);
@@ -288,11 +288,11 @@ cp_r (char *src, const char *dest)
 }
 
 static gchar *
-form_dir_path (char *file_name, char *delim)
+form_dir_path (gchar *file_name, const gchar *delim)
 {
 	GString *path = g_string_new (NULL);
 	gchar *dir_path;
-	char *token;
+	gchar *token;
 
 	token = strtok (file_name, delim);
 	while (token != NULL) {
@@ -305,11 +305,12 @@ form_dir_path (char *file_name, char *delim)
 	return dir_path;
 }
 
-static gchar*
-get_contacts_dir_from_filename(const char *migr_file)
+static gchar *
+get_contacts_dir_from_filename(const gchar *migr_file)
 {
-	char *file_to_be_migrated = g_strdup (migr_file);
-	char *dot, *delim = "_", *file_name;
+	gchar *file_to_be_migrated = g_strdup (migr_file);
+	gchar *dot, *file_name;
+	const gchar *delim = "_";
 	gchar *dir_path = NULL;
 
 	dot = strchr (file_to_be_migrated, '.');
@@ -376,11 +377,11 @@ migrate_contacts (gchar *src_path, const gchar *dest_path)
 							NULL);
 
 				/* Create destination dir, and copy the files */
-       				if (g_mkdir_with_parents (contacts_dir, 0777) == -1) {
+				if (g_mkdir_with_parents (contacts_dir, 0777) == -1) {
 					ret = FALSE;
 					g_free (dest_file);
 					g_free (contacts_dir);
-                			continue;
+					continue;
 				}
 
 				src_file = g_build_filename ( src_path,
@@ -458,7 +459,7 @@ exchange_migrate (const CORBA_short major,
 		  const CORBA_short minor,
 		  const CORBA_short revision,
 		  const gchar *base_dir,
-		  char *account_filename)
+		  gchar *account_filename)
 {
 	gboolean ret = TRUE;
         struct stat st;
@@ -473,14 +474,14 @@ exchange_migrate (const CORBA_short major,
 			return;
 
 		/* This is not needed if done by cp_r() */
-        	if (stat (base_dir, &st) == -1) {
+		if (stat (base_dir, &st) == -1) {
 			if (errno != ENOENT ||
 			    g_mkdir_with_parents (base_dir, 0777) == -1) {
-                       		printf ("Failed to create directory `%s': %s",
+				printf ("Failed to create directory `%s': %s",
 				base_dir, g_strerror (errno));
-                        	return;
-                	}
-        	}
+				return;
+			}
+		}
 
 		src_path = g_build_filename (g_get_home_dir (),
 					     "evolution",
